# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2012 Terkel Sorensen
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import json, urllib2, webbrowser
from subprocess import Popen, PIPE, STDOUT 
from gi.repository import Gtk, WebKit # pylint: disable=E0611

from bitcoincharts_lib.helpers import get_builder
import gettext
from gettext import gettext as _
gettext.textdomain('bitcoincharts')

class DonateDialog(Gtk.Dialog):
    __gtype_name__ = "DonateDialog"
    #This is the bitcoin adress where all endusers donation will go to.
    #As a develper you only need to replace it with your one bitcoin adress.
    
    def __new__(cls):
        """Special static method that's automatically called by Python when 
        constructing a new instance of this class.
        
        Returns a fully instantiated DonateDialog object.
        """
        builder = get_builder('DonateDialog')
        new_object = builder.get_object('donate_dialog')
        new_object.finish_initializing(builder)
        return new_object

    def finish_initializing(self, builder):
        """Called when we're finished initializing.

        finish_initalizing should be called after parsing the ui definition
        and creating a DonateDialog object with it in order to
        finish initializing the start of the new DonateDialog
        instance.
        """

        ######################################################################################
        ###########################  DonateDialog-setup  #####################################
        ######################################################################################
        self.btc_adress = "16626BhMsp7prm9ijLZGPyH4dWhsCLfYam" # <--add your btc-address here
        self.paypal_email = "terkelsorensen@gmail.com" # <--add your PayPal-email here
        ######################################################################################
        ###########################         END          #####################################
        ######################################################################################

        #Get current btc weighted prices from http://bitcoincharts.com
        req = urllib2.Request("http://bitcoincharts.com/t/weighted_prices.json")
        opener = urllib2.build_opener()
        f = opener.open(req)
        self.json = json.loads(f.read())
        self.btc_weighted_prices = self.json["USD"]["30d"]

        # Get a reference to the builder and set up the signals.
        self.builder = builder
        self.ui = builder.get_ui(self)
        
        #adds ubuntu style to 'toolbar'
        toolbar = self.builder.get_object("toolbar_donate")
        context = toolbar.get_style_context()
        context.add_class(Gtk.STYLE_CLASS_PRIMARY_TOOLBAR)

        #gets endusers select btc amount 
        self.cbt_select_btc_amount = self.builder.get_object("cbt_select_btc_amount")
        self.cbt_select_btc_amount.set_active(0)

        #gets endusers select PayPal currency(US-dollars or Euro etc..)
        self.cbt_select_paypal_currency = self.builder.get_object("cbt_select_paypal_currency")
        self.cbt_select_paypal_currency.set_active(0)

        #gets endusers select PayPal donate amount
        self.entry_bitcoin_amount = self.builder.get_object("entry_bitcoin_amount")

        #gets the webkit and the scrolledwindow object.
        self.btc_scrolledwindow = self.builder.get_object("scrolledwindow_request_for_bitcoins")
        self.btc_webview = WebKit.WebView()

        #show QR-tag in btc_webview
        self.btc_webview.open("https://chart.googleapis.com/chart?chs=260x260&cht=qr&choe=UTF-8&chl=bitcoin:"+self.btc_adress+"?amount="+self.cbt_select_btc_amount.get_active_text()[3:])
        self.btc_webview.show()

        #addes webview to scrolledwindow, then webview.open(url)
        self.btc_scrolledwindow.add(self.btc_webview)

        #show the request wallet btc-address
        label_btc_address = self.builder.get_object("label_btc_address")
        label_btc_address.set_text(self.btc_adress)

########Stylesheet
        self.css ="<style>h1{font-size:14px;} #item_price_1{font-size:20px;padding:0px 5px;border:1px solid black;width:50px;-webkit-border-radius: 5px;-moz-border-radius: 5px;border-radius: 5px;}</style>"

    def on_btn_google_donate_clicked(self, widget):
        url = "https://checkout.google.com/buttons/checkout.gif?merchant_id="+self.google_merchant_id+"654861252334212&w=180&h=46&style=trans&variant=text&loc=en_US"
        #open default browser to complete the donate proccess on PlayPal´s webpage
        webbrowser.open_new(url)

    def on_btn_paypal_doante_clicked(self, widget):
        url = "https://www.paypal.com/cgi-bin/webscr?cmd=_donations&"
        parms = [
                    "business="+self.paypal_email, 
                    "lc=US",
                    "amount="+self.entry_bitcoin_amount.get_text(),
                    "currency_code="+self.cbt_select_paypal_currency.get_active_text(),
                    "no_note=0",
                    "bn=PP%2dDonationsBF%3abtn_donateCC_LG%2egif%3aNonHostedGuest"
                ]
        #open default browser to complete the donate proccess on PlayPal´s webpage
        webbrowser.open_new(url+"&".join(parms))

    def on_cbt_select_btc_amount_changed(self, widget):
        #show some info abort where data for bitcoin cal is from
        label_bitcoincharts_info = self.builder.get_object("label_bitcoincharts_info")
        label_bitcoincharts_info.set_text("Btc-rate in dollars is base on data from Bitcoincharts.com")

        #show btc prices in dollars
        label_btc_in_dollars = self.builder.get_object("label_btc_in_dollars")
        label_btc_in_dollars.set_text(" = $"+str(float(self.cbt_select_btc_amount.get_active_text()[3:])*float(self.btc_weighted_prices)))

        #show QR-tag in btc_webview
        self.btc_webview.open("https://chart.googleapis.com/chart?chs=260x260&cht=qr&choe=UTF-8&chl=bitcoin:"+self.btc_adress+"?amount="+self.cbt_select_btc_amount.get_active_text()[3:])
        self.btc_webview.show()

        pass

    def on_btn_cancel_clicked(self, widget, data=None):
        """The user has elected cancel changes.
        
        Called before the dialog returns Gtk.ResponseType.CANCEL for run()
        """
        self.hide()
        pass

if __name__ == "__main__":
    dialog = DonateDialog()
    dialog.show()
    Gtk.main()
